@@ -55,8 +55,8 @@ class SegmentationDataset(Dataset):
         mask_key=None
     ) -> None:
         self.input_csv_path = input_csv_path
-        self.df = pd.read_csv(input_csv_path)
         self.root_dir = root_dir
+        self.df = pd.read_csv(input_csv_path)
         self.transform = None if augmentation_list is None \
             else load_augmentation_object(augmentation_list)
         self.data_loader = data_loader
@@ -85,9 +85,10 @@ class SegmentationDataset(Dataset):
         key = self.image_key if key is None else key
         image_path = str(self.df.iloc[idx][key])
         if self.root_dir is not None:
-            image_path = os.path.join(
+            return os.path.join(
                 self.root_dir,
-                image_path
+                image_path if not image_path.startswith(os.path.sep) \
+                    else image_path[1::]
             )
         return image_path
 
